@@ -5,7 +5,7 @@ from ..utils.config import Config
 
 
 @click.group(invoke_without_command=True)
-@click.version_option(version="0.1.0")
+@click.version_option(version=__import__("polyterm").__version__)
 @click.pass_context
 def cli(ctx):
     """PolyTerm - Terminal-based monitoring for PolyMarket
@@ -24,7 +24,7 @@ def cli(ctx):
 
 
 # Import commands
-from .commands import monitor, watch, whales, replay, portfolio, export_cmd, config_cmd
+from .commands import monitor, watch, whales, replay, portfolio, export_cmd, config_cmd, live_monitor
 
 # Register commands
 cli.add_command(monitor.monitor)
@@ -34,6 +34,7 @@ cli.add_command(replay.replay)
 cli.add_command(portfolio.portfolio)
 cli.add_command(export_cmd.export)
 cli.add_command(config_cmd.config)
+cli.add_command(live_monitor.live_monitor)
 
 
 if __name__ == "__main__":
